CountDownProgress class

Constructors

CountDownProgress(Duration remaining, Duration total, double progress, CountdownStatus status)

Properties

hashCode int
The hash code for this object.
no setterinherited
progress double
final
remaining Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status CountdownStatus
final
total Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited