CountdownFormatUtils class

倒计时格式化工具类(支持多格式/补零/自适应)

Constructors

CountdownFormatUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

formatAuto(Duration duration) String
自适应格式化(根据时长自动选择格式)
formatChinese(Duration duration) String
格式化为中文描述(如“1小时2分3秒”)
formatHHmmss(Duration duration) String
格式化时长为 HH:mm:ss 格式(自动补零)
formatMmss(Duration duration) String
格式化时长为 mm:ss 格式(自动补零)
formatSs(Duration duration) String
格式化时长为 ss 格式(自动补零)