CountDownConfig class
倒计时配置
Constructors
- CountDownConfig({required Duration duration, bool autoPlay = true, Duration interval = const Duration(seconds: 1), bool resetToOriginal = true, VoidCallback? onDone})
Properties
- autoPlay → bool
-
是否自动开始倒计时
final
- duration → Duration
-
倒计时总时长
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- interval → Duration
-
倒计时刷新周期(默认1秒)
final
- onDone → VoidCallback?
-
倒计时结束回调
final
- resetToOriginal → bool
-
重置时是否恢复初始时长(默认true,支持保留当前剩余时长重置)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override