EasyCountdownController class
倒计时控制器
Constructors
- EasyCountdownController({void onProgress(CountDownProgress)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onPause ↔ VoidCallback?
-
getter/setter pair
- onProgress → void Function(CountDownProgress)?
-
final
- onReset ↔ VoidCallback?
-
getter/setter pair
- onStart ↔ VoidCallback?
-
getter/setter pair
- remainingDuration → Duration
-
获取当前剩余时长(实时同步)
no setter
-
remainingDurationNotifier
→ ValueNotifier<
Duration> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setRemainingDuration
↔ ValueSetter<
Duration> ? -
getter/setter pair
- status → CountdownStatus
-
获取当前倒计时状态(实时同步)
no setter
-
statusNotifier
→ ValueNotifier<
CountdownStatus> -
final
Methods
-
dispose(
) → void - 销毁控制器
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → void - 暂停倒计时
-
reset(
) → void - 重置倒计时
-
start(
) → void - 开始倒计时
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRemainingDuration(
Duration duration) → void - 手动设置剩余时长
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited